@@ -10,11 +10,11 @@ async fn main() -> Result<()> {
         .filter_level(log::LevelFilter::Debug)
         .init();
     let websocket_server = Builder::new("0.0.0.0:8888")
-        .set_config(WebSocketConfig{
+        .set_config(WebSocketConfig {
             max_send_queue: None,
-            max_message_size: Some(1024*1024),
-            max_frame_size: Some(256*1024),
-            accept_unmasked_frames: false
+            max_message_size: Some(1024 * 1024),
+            max_frame_size: Some(256 * 1024),
+            accept_unmasked_frames: false,
         })
         .set_connect_event(|addr| {
             info!("{} connect", addr);
